@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1300';
+our $VERSION = '0.1301';
 
 use Moo;
 use strictures 2;
@@ -26,6 +26,13 @@ has position => (
 );
 
 
+has absolute => (
+    is      => 'ro',
+    isa     => \&_boolean,
+    default => sub { 0 },
+);
+
+
 has strings => (
     is      => 'ro',
     isa     => \&_positive_int,
@@ -235,7 +242,7 @@ sub draw {
             }
 
             if ( $note =~ /[xX]/ ) {
-                print "X at 0,$string\n" if $self->verbose;
+                warn "X at 0,$string\n" if $self->verbose;
 
                 $i->string(
                     font  => $font,
@@ -251,7 +258,7 @@ sub draw {
                 my $temp = $self->fretboard->{$string}[0];
                 push @chord, $temp;
 
-                print "O at 0,$string = $temp\n" if $self->verbose;
+                warn "O at 0,$string = $temp\n" if $self->verbose;
 
                 $i->string(
                     font  => $font,
@@ -267,13 +274,17 @@ sub draw {
                 my $temp = $self->_note_at($string, $note);
                 push @chord, $temp;
 
-                print "Dot at $note,$string = $temp\n" if $self->verbose;
+                warn "Dot at $note,$string = $temp\n" if $self->verbose;
+
+                my $y = $self->absolute
+                    ? $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE
+                    : $SPACE + $SPACE / 2 + ($note - 1) * $SPACE;
 
                 $i->circle(
                     color => $self->dot_color,
                     r     => $SPACE / 5,
                     x     => $SPACE + ($self->strings - $string) * $SPACE,
-                    y     => $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE,
+                    y     => $y,
                 );
             }
 
@@ -284,7 +295,7 @@ sub draw {
         # Print the chord name if requested
         if ( $self->showname ) {
             my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
-            print "Chord = $chord_name\n" if $self->verbose;
+            warn "Chord = $chord_name\n" if $self->verbose;
             $i->string(
                 font  => $font,
                 text  => $chord_name,
@@ -385,10 +396,13 @@ sub _draw_horiz {
         # Draw the note/mute markers
         my $string = 1;
         for my $note ( reverse split //, $chord ) {
-            next if $note =~ /-/;
+            if ( $note =~ /-/ ) {
+                $string++;
+                next;
+            }
 
             if ( $note =~ /[xX]/ ) {
-                print "X at fret:0, string:$string\n" if $self->verbose;
+                warn "X at fret:0, string:$string\n" if $self->verbose;
 
                 $i->string(
                     font  => $font,
@@ -404,7 +418,7 @@ sub _draw_horiz {
                 my $temp = $self->fretboard->{$string}[0];
                 unshift @chord, $temp;
 
-                print "O at fret:0, string:$string = $temp\n" if $self->verbose;
+                warn "O at fret:0, string:$string = $temp\n" if $self->verbose;
 
                 $i->string(
                     font  => $font,
@@ -420,13 +434,17 @@ sub _draw_horiz {
                 my $temp = $self->_note_at($string, $note);
                 unshift @chord, $temp;
 
-                print "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
+                warn "Dot at fret:$note, string:$string = $temp\n" if $self->verbose;
+
+                my $x = $self->absolute
+                    ? $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE
+                    : $SPACE + $SPACE / 2 + ($note - 1) * $SPACE;
 
                 $i->circle(
                     color => $self->dot_color,
                     r     => $SPACE / 5,
+                    x     => $x,
                     y     => $SPACE + ($string - 1) * $SPACE,
-                    x     => $SPACE + $SPACE / 2 + ($posn - 1 + $note - 1) * $SPACE,
                 );
             }
 
@@ -437,7 +455,7 @@ sub _draw_horiz {
         # Print the chord name if requested
         if ( $self->showname ) {
             my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
-            print "Chord = $chord_name\n" if $self->verbose;
+            warn "Chord = $chord_name\n" if $self->verbose;
             $i->string(
                 font  => $font,
                 text  => $chord_name,
@@ -489,6 +507,11 @@ sub _positive_int {
     die "$arg is not a positive integer" unless $arg =~ /^[1-9]\d*$/;
 }
 
+sub _boolean {
+    my ($arg) = @_;
+    die "$arg is not a Boolean value" unless $arg =~ /^[10]$/;
+}
+
 1;
 
 __END__
@@ -503,26 +526,28 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1300
+version 0.1301
 
 =head1 SYNOPSIS
 
   use Music::FretboardDiagram;
 
   my $dia = Music::FretboardDiagram->new(
-    chord   => 'xx0232',
-    frets   => 1,
-    outfile => 'Dm',
-    font    => '/path/to/TTF/font.ttf',
+    chord    => 'xx0232',
+    frets    => 5,     # the default
+    position => 1,     # the default
+    font     => '/path/to/TTF/font.ttf',
+    outfile  => 'Dm',
+    type     => 'png', # the default
   );
 
   $dia = Music::FretboardDiagram->new(
-    chord   => [[1,'022000'], [2,'--1342'], [7,'-13321']], # Em chords
-    frets   => 13,
-    outfile => 'fretboard',
-    font    => '/path/to/TTF/font.ttf',
-    horiz   => 1,
-    verbose => 1,
+    chord    => [[1,'022000'], [2,'--1342'], [7,'-13321']], # Em chords
+    frets    => 13,
+    absolute => 1,
+    outfile  => 'fretboard',
+    horiz    => 1,
+    verbose  => 1,
   );
 
   $dia->chord('xx0232');          # set a new chord
@@ -603,6 +628,17 @@ horizontally, the position is rendered above the first fret.
 
 Default: C<1>
 
+=head2 absolute
+
+  $absolute = $dia->absolute;
+
+Use an absolute neck position for rendering a chord on a full length
+fretboard.
+
+If not set, the chord will be rendered relative to the first fret.
+
+Default: C<0>
+
 =head2 strings
 
   $strings = $dia->strings;
